
#include "meanvar.h"

// x is first data column, contains x-values
// s is second data column, contains sigmas (if any) or weights (if any)

// to test if sum of s values is an integer
bool integer(dbl i)
{
  if (i==(int)i) return true;
  return false;
}


void calculate(dvec& x, dvec& s, opts& o, result& r)
{
  uns n1 = x.size();                                      // no of x-values
  uns npts;                                      // total no of data points
  uns nu;                          // degs of freedom, equal to npts-1 here
  uns n2 = s.size();                        // zero if no sigmas or weights
  uns k;
  dbl ss;                                       // sum of s values for test
  dbl w;                                                     // weight w[k]
  dbl sw;                                                    // sum of w[k]
  dbl sww;                                              // sum of w[k]*w[k]
  dbl sx;                                               // sum of w[k]*x[k]
  dbl sxx;                                         // sum of w[k]*x[k]*x[k]

  dbl mean;                                                  // sample mean
  dbl var;                                               // sample variance
  dbl varmean;                                          // variance of mean
  dbl smean;              // std deviation of mean, usually t*sqrt(varmean)
  dbl chisq;                                                  // chi-square
  dbl t;                                                // student t-factor
  dbl conf = o.conf/100.0;                            // default conf level

  if (n2 && o.ignore_s) {           // if n2 and ignore_s, shrink s to zero
    for (k=0 ; k < n2 ; k++) s.pop_back();
    n2=0;                                                   // and set n2=0
  }

  ss = w = sw = sww = sx = sxx = 0.0;

  for (k = 0 ; k < n1 ; k++) {                     // calculate needed sums
    if (n2 == 0) {                    // if sigmas ignored or not supplied,
      s.push_back(sqrt(n1));          // fill s to make w=1/n1, so sw = 1.0
    }
    if (o.weights) {  // s contains weights or "repeats" (frequency of x's)
      w = s[k];
    }
    else {                              // s was either empty or has sigmas
      w = 1.0/(s[k]*s[k]);                                  // this is w[k]
    }
    ss += s[k];
    sw += w;                                             // add up the w[k]
    sww += w*w;                                         // add up w[k]*w[k]
    sx += w*x[k];                               // add up the weighted x[k]
    sxx += w*x[k]*x[k];                    // add up the weighted x[k]*x[k]
  }

  // if sum of s is an integer without a -w option (unlikely),
  // issue a warning:
  if (integer(ss) && !o.weights && !o.ignore_s && n2 != 0) {
    warn(" I'm suspicious. Your 2nd column sums to an integer.\n     Did you forget the --weights (or -w) option?");
  }
  // if sum of s is not an integer but a -w option has been
  // given, it's an error:
  if (!integer(ss) && o.weights && n2 != 0 && !o.ignore_s) {
    err(" You have included non-integer weights, but have specified\n    the --weights (or -w) option, so meanvar won't work.  Try it\n    again without the --weights option.");
  }

  if (o.weights) npts = sw;
  else npts = n1;

  nu = npts - 1;                               // the usual degs of freedom

  mean = sx/sw;                                              // sample mean
  if (o.weights) {
    var = (sxx - sx*sx/sw)/(sw - 1);   // use this when wts are frequencies
  }
  else {
    var = (sw*sxx - sx*sx)/(sw*sw - sww);                    // gsl formula
  }

  // NOTE: If gsl formula is used with x = {2,2,4,5,5,5}, var=2.1667,
  // but if x = {2,4,5} with weights = {2,1,3}, var = 2.955.  We
  // should get the same result for both.  Therefore, do not use
  // the gsl formula when the -w option is used, where the
  // weights are frequencies (or "repeats") of x-occurances.
  // There is confusion out there on this point, but the code above
  // will do it correctly.

  // cout << "npts = " << npts << "\n";
  // cout << "nu = " << nu << "\n";
  // cout << "sw = " << sw << "\n";
  // cout << "sww = " << sww << "\n";
  // cout << "sum = sxx - sx*sx/sw = " << sxx - sx*sx/sw << "\n";
  t = student(nu, conf);                                // student-t factor

  if (!n2 && o.weights) {                // no 2nd column, but -w specified
    err(" You have not supplied a 2nd column, but have specified\n    the --weights option. Try it again without --weights.");
  }
  if (n2 && !o.weights) {              // sigmas (not weights) are supplied
    varmean = 1.0/sw;
    smean = sqrt(varmean);           // don't use student-t if sigs present
  }
  else {
    varmean = var/npts;
    smean = t*sqrt(varmean);                        // but use t if no sigs
  }

  chisq = sxx - sx*sx/sw;                                     // chi-square
  r.npts = npts;                                   // store results in r...
  r.n2 = n2;                                  // to see if there are sigmas
  r.mean = mean;
  r.var = var;
  r.stddev = sqrt(var);
  r.smean = smean;
  r.chisq = chisq;
  r.alpha = gammq(0.5*nu, 0.5*chisq);
}
