//
// prints a help message on the screen
//
#include "config.h"                                // for PACKAGE_BUGREPORT and WINCMD
#include "meanvar.h"

void prn_info(char** argv)
{
  string pgname = basename(argv[0]);                 // chops long pathname

  if (pgname.rfind(".exe") != string::npos) {
    pgname.replace(pgname.find(".exe"),4,"");
  }

  #ifdef WINCMD
  cout <<
    "\n " << pgname << ", when given a single"
    " argument datafile (the name of your data\n"
    " file), will calculate the sample mean (along with its uncertainty),\n"
    " the sample variance (along with its square root, the standard deviation),\n"
    " and for one special case, a value of chi-square, along with a value of\n"
    " alpha, the probability that a larger value of chi-square would be obtained\n"
    " for an equivalent data set, assuming the data to be drawn from a normal\n"
    " (Gaussian) distribution.\n\n"

    " By default, the results will appear on the screen of your monitor.  If\n"
    " desired, they may be re-directed to a file, by giving a command such as\n"
    " meanvar datafile > outfile.\n\n"

    " The datafile must be prepared in one of three formats, described below.\n"
    " For all three, blank lines and lines of text (e.g., comments) are ignored.\n\n"

    "  (a) The simplest datafile consists of a single column of numbers (either\n"
    "      integers or decimal numbers), with one number per row.  (Such numbers\n"
    "      are typically called \"x-values\".)\n\n"

    "  (b) A datafile may alternatively consist of two columns of numbers, with\n"
    "      the first being x-values, and the second column being integer weights.\n"
    "      Such weights denote the frequency (repeats) of the associated x-value.\n"
    "      The sum of the weights will be the total number of data points analyzed.\n"
    "      For this format, every row must consist of two numbers, and the option\n"
    "      \"--weights\" (or \"-w\") must be provided to meanvar.\n\n"

    "  (c) For the third alternative, there is also a second column of numbers,\n"
    "      but in this case, the second number must be an independent estimate of\n"
    "      sigma (typically a \"standard error\", or \"standard deviation\") for the\n"
    "      associated x-value.  For this case, meanvar will calculate a value of\n"
    "      chi-square, along with a value of alpha, which may be used to judge\n"
    "      whether the set of x-values can be well described by a single number.\n"
    "      A discussion of this use of the chi-square statistic, as applied to the\n"
    "      determination of the mass if the Z-zero boson at CERN, appears in our\n"
    "      lab manual.  Note that here no Student t-factor is invoked.\n\n"

    " Two additional options---seldom used---are available:\n\n"

    "   --ignore_s: In case you might want to ignore the values of the second\n"
    "     column of your datafile, this option may be invoked.  (Do not combine\n"
    "     with the --weights option.)\n\n"
    "   --conf n:  This option may be invoked in case you might want to specify a\n"
    "     confidence level other than the default 68.27 percent level.  While it\n"
    "     is customary among physicists to use our default level, those doing\n"
    "     polling, or those in other fields (e.g., industrial testing), often\n"
    "     use a 95 percent confidence level (--conf 95), which will have the\n"
    "     effect of increasing the standard error (uncertainty) in the calculation\n"
    "     of the sample mean, since the Student t-factor will be larger.\n\n"

    " If you have questions, comments or bug reports, write to me:\n"
    "    Peter Scott <" << PACKAGE_BUGREPORT << ">.\n\n"

    "\t\t ++++++++++++++++++++++++++++++++++++++++++\n";
  #else
  cout <<
    "\n \033[1m" << pgname << "\033[0m, when given a single"
    " argument \033[1mdatafile\033[0m (the name of your data\n"
    " file), will calculate the sample mean (along with its uncertainty),\n"
    " the sample variance (along with its square root, the standard deviation),\n"
    " and for one special case, a value of chi-square, along with a value of\n"
    " alpha, the probability that a larger value of chi-square would be obtained\n"
    " for an equivalent data set, assuming the data to be drawn from a normal\n"
    " (Gaussian) distribution.\n\n"

    " By default, the results will appear on the screen of your monitor.  If\n"
    " desired, they may be re-directed to a file, by giving a command such as\n"
    " \033[1mmeanvar datafile > outfile\033[0m.\n\n"

    " The \033[1mdatafile\033[0m must be prepared in one of three formats, described below.\n"
    " For all three, blank lines and lines of text (e.g., comments) are ignored.\n\n"

    "  (a) The simplest \033[1mdatafile\033[0m consists of a single column of numbers (either\n"
    "      integers or decimal numbers), with one number per row.  (Such numbers\n"
    "      are typically called \"x-values\".)\n\n"

    "  (b) A \033[1mdatafile\033[0m may alternatively consist of two columns of numbers, with\n"
    "      the first being x-values, and the second column being integer weights.\n"
    "      Such weights denote the frequency (repeats) of the associated x-value.\n"
    "      The sum of the weights will be the total number of data points analyzed.\n"
    "      For this format, every row must consist of two numbers, and the option\n"
    "      \"--weights\" (or \"-w\") must be provided to meanvar.\n\n"

    "  (c) For the third alternative, there is also a second column of numbers,\n"
    "      but in this case, the second number must be an independent estimate of\n"
    "      sigma (typically a \"standard error\", or \"standard deviation\") for the\n"
    "      associated x-value.  For this case, meanvar will calculate a value of\n"
    "      chi-square, along with a value of alpha, which may be used to judge\n"
    "      whether the set of x-values can be well described by a single number.\n"
    "      A discussion of this use of the chi-square statistic, as applied to the\n"
    "      determination of the mass if the Z-zero boson at CERN, appears in our\n"
    "      lab manual.  Note that here no Student t-factor is invoked.\n\n"

    " Two additional options---seldom used---are available:\n\n"

    "   --ignore_s: In case you might want to ignore the values of the second\n"
    "     column of your \033[1mdatafile\033[0m, this option may be invoked.  (Do not combine\n"
    "     with the --weights option.)\n\n"
    "   --conf \033[1mn\033[0m:  This option may be invoked in case you might want to specify a\n"
    "     confidence level other than the default 68.27 percent level.  While it\n"
    "     is customary among physicists to use our default level, those doing\n"
    "     polling, or those in other fields (e.g., industrial testing), often\n"
    "     use a 95 percent confidence level (--conf 95), which will have the\n"
    "     effect of increasing the standard error (uncertainty) in the calculation\n"
    "     of the sample mean, since the Student t-factor will be larger.\n\n"

    " If you have questions, comments or bug reports, write to me:\n"
    "    Peter Scott <" << PACKAGE_BUGREPORT << ">.\n\n"

    "\t\t ++++++++++++++++++++++++++++++++++++++++++\n";
    #endif


  prn_usage(argv);
}
